/*
 *
 *    GALLERY 
 *
 */


/* previews */

#adi_fancybox_wrapper .tileItem {
    font-size: 12px;
    float: left;
    margin: 0.75em 1.5em 0.75em 0;
    padding: 1em;
    border-radius: 10px;
    -moz-box-shadow: 0 0 5px #888;
    -webkit-box-shadow: 0 0 5px #888;
    box-shadow: 0 0 5px #888;
}

.adiGalItem .preview {
    height: 128px;
    width: 128px;
    text-align: center;
}

/* titles and descs */

.adiGalItem .title {
    width: 128px;
    position: relative;
    top: 1em;
    height: 1.5em;
    line-height: 1.5em;
    overflow: hidden;
}

.adiGalItem .title:hover {
    overflow: visible;
}

/*
.adiGalItem .title span {
    width: 100px;
    overflow: hidden;
}
*/

.adiGalItem .desc {
    position: absolute;
    font-size: 90%;
    display: none;
}

.adiGalItem .title:hover .desc {
    display: block;
}

/* icons */ 

.adiGalItem .title img {
    float: left;
    margin-right: 0.5em;
}

/*
 *
 *    GALLERIESLIST
 *
 */


/* fancyboxframe */

.template-adi_suite_gallerylist #fancybox-wrap {
    position: absolute;
    top: 0!important;
    left: 0!important;
    width: 99.5%!important;
    height: 99.5%!important;
    padding: 0;
    overflow: hidden!important;
}

.template-adi_suite_gallerylist #fancybox-content, 
.template-adi_suite_gallerylist #fancybox-outer,
.template-adi_suite_gallerylist #fancybox-inner {
    width: 100%!important;
    height: 100%!important;
    top: 0!important; left: 0!important;
    background: transparent !important;
}

.template-adi_suite_gallerylist #fancybox-close {
    top: 0;
    right: 0;
}

.template-adi_suite_gallerylist #fancybox-content {
    border: none !important;
}

/* previews */

.template-adi_call_galleryview #adi_fancybox_wrapper .tileItem {
    font-size: 6px;
    height: 64px;
    width: 64px;
    overflow: hidden;
}

.template-adi_call_galleryview .adiGalItem .preview,
.template-adi_call_galleryview .adiGalItem .preview img {
    height: 64px;
    width: 64px;
}

.template-adi_call_galleryview .title {
    display: none;
}

/*
 *
 *    FANCYBOX POPUP
 *
 */

#fancybox-overlay {
    opacity: 0.666 !important;
}

body.template-adi_call_galleryview #fancybox-overlay {
    background-color: transparent !important;
}

body.template-adi_call_galleryview { 
    background-color: transparent !important; 
}

#fancybox-outer { 
    margin-left: auto!important; 
    margin-right: auto!important; 
} 


/* 
 * 
 *
 *    POPUPITEM 
 *
 */

/* titles and descs */

#fancybox-title-float-main {
    background: url() #333;
    color: #fff;
    padding: 0 0.5em;
    line-height: 1.5em;
    border-radius: 0.5em;
}

#fancybox-title-float-left,
#fancybox-title-float-right {
    display: none;
}

#fancybox-title-float-main div:nth-child(1) {
    text-align: center;
}

#fancybox-title-float-main div:nth-child(2) {
    font-style: italic;
    font-size: 88%;
}

/* arrows- and close-buttons */

#fancybox-close {
    position: absolute;
    top: -27px;
    right: -27px;
}

#fancybox-close,
#fancybox-left-ico,
#fancybox-right-ico {
    background-image: url(++resource++adi_fancybox.png);
    background-repeat: no-repeat;
}

#fancybox-left:hover {
    margin-left: -50px;
    margin-bottom: -10px;
}

#fancybox-right:hover {
    margin-right: -50px;
    margin-bottom: -10px;
}

/* 
 *
 * 
 *    FLOWPLAYER 
 *
 *
 */

.template-adi_suite_flowplayer {
    background: #333;
}

#player {
    display: block;
    height: 330px;
    width: 500px;
    background: url(++resource++play.png) no-repeat -8px -3px;
    position: absolute;
    left: 30px;
    top: 10px;
}

.template-adi_suite_flowplayer #fancybox-frame, 
.template-adi_suite_galleryview #fancybox-frame, 
.template-adi_call_galleryview #fancybox-frame { 
    overflow: hidden; 
}

/* NON-DISPLAYS */ 

.template-adi_suite_galleryview .newsImageContainer,
.template-adi_call_galleryview #fancybox-close, 
.template-adi_suite_gallerylist #fancybox-title,
.portaltype-gallery .QuickUploadPortlet #label-upload, 
.portaltype-gallery .QuickUploadPortlet .portletHeader {
   display: none !important;
}

/* EOF */    
